################################################################################
## 
## Main script for reproducing
## 
## World Bank Working Paper Series 
##
## Implementing 30x30: Lessons From Country Case Studies
##
## Authors: Susmita Dasgupta, Brian Blankespoor, David Wheeler
##
################################################################################

get_current_file_path <- function(){
     this_file <- grep("^--file=", commandArgs(), value = TRUE)
     this_file <- gsub("^--file=", "", this_file)
     if (length(this_file) == 0) this_file <- rstudioapi::getSourceEditorContext()$path
        return(dirname(this_file))
      }

# set working directory
wkdir <- get_current_file_path()
print(wkdir)
setwd(wkdir)

print(Sys.time())

# stata path here #
stata_path <- '"C:/Program Files/Stata18/StataMP-64.exe"'  


# libraries
source(file.path(wkdir,'biod_pa_wp_global_libraries.R'))
biod_pa_wp_global_libraries_dofn <- file.path(wkdir,'biod_pa_wp_global_libraries.do')
system(paste(stata_path, "/e do", biod_pa_wp_global_libraries_dofn),show.output.on.console = TRUE)

## Turn off sf's spherical ("S2") backend
sf_use_s2(FALSE) 
today <- Sys.Date()

ddh_vers <- '2025-01-17'
run_vers <- '2024-09-17'

#renv::init()
tbldir <- file.path(wkdir,'tables_rp',sprintf("vers%s",ddh_vers)) # reproduced tables
figdir <- file.path(wkdir,'figures_rp',sprintf("vers%s",ddh_vers)) # reproduced figures
xfun::dir_create(tbldir)
xfun::dir_create(figdir)

## load adm0 map for selections
source(file.path(wkdir,'biod_pa_wp_load_ddh_boundary_data.R'))

## Figure 1:  Mean protected-area size vs. country area
## Table 1:  Regression results
biod_pa_wp_fig01_fn <- file.path(wkdir,'biod_pa_wp_fig01_tbl01_country_size_vs_PA_size.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig01_fn),show.output.on.console = TRUE)

## Figure 2:  Brazil - Images of some unprotected species (photos)

## Figure 3:  Brazil - Unprotected species
##  3a : vertebrates
source(file.path(wkdir,'biod_pa_wp_fig03a_unprotected_brazil_vertebrates.R'))
##  3b : plants
source(file.path(wkdir,'biod_pa_wp_fig03b_unprotected_brazil_plants.R'))
##  3c : Arthropods
source(file.path(wkdir,'biod_pa_wp_fig03c_unprotected_brazil_arthropods.R'))

## Figure 4 : Brazil - Top 4 candidate areas for new protection
library(terra)
source(file.path(wkdir,'biod_pa_wp_fig04_top4_priorities_brazil.R'))

## Figure 5:  Cameroon - Images of unprotected species (photos)

## Figure 6:  Cameroon - Unprotected species
##   6a : vertebrates
source(file.path(wkdir,'biod_pa_wp_fig06a_unprotected_cameroun_vertebrates.R'))
##   6b : plants
source(file.path(wkdir,'biod_pa_wp_fig06b_unprotected_cameroun_plants.R'))
##   6c : Arthropods
source(file.path(wkdir,'biod_pa_wp_fig06c_unprotected_cameroun_arthropods.R'))

## Figure 7: Top 4 priority areas in Cameroon
source(file.path(wkdir,'biod_pa_wp_fig07_top4_priorities_cameroon.R'))

## Figure 8:  Brazil and Cameroon - Full protection areas for priority group 1
source(file.path(wkdir,'biod_pa_wp_fig08_full_protection.R'))

## Figure 9:  South Africa - Selected unprotected species (photos)

## Figure 10: Top 3 priority areas in South Africa
source(file.path(wkdir,'biod_pa_wp_fig10_top4_priorities_south_africa.R'))

## Figure 11: Top 3 priority areas in Costa Rica
source(file.path(wkdir,'biod_pa_wp_fig11_top4_priorities_costa_rica.R'))

## Figure 12:  Ecuador - Incremental protected areas by new species coverage percent decile
source(file.path(wkdir,'biod_pa_wp_fig12_ecuador.R'))

## Figure 13:  Papua New Guinea - Incremental protected areas by new species coverage percent decile
source(file.path(wkdir,'biod_pa_wp_fig13_papua_new_guinea.R'))

## Figure 14:  Ecuador - Species protection vs. land in protected areas
biod_pa_wp_fig14_fn <- file.path(wkdir,'biod_pa_wp_fig14_Ecuador_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig14_fn),show.output.on.console = TRUE)

## Figure 15:  Papua New Guinea - Species protection vs. land in protected areas
biod_pa_wp_fig15_fn <- file.path(wkdir,'biod_pa_wp_fig15_PNG_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig15_fn),show.output.on.console = TRUE)

## Figure 16: Top 4 marine priority areas in Philippines
source(file.path(wkdir,'biod_pa_wp_fig16_top4_priorities_philippines.R'))

## Figure 17:  Philippines - Marine species protection vs. territory in EEZ
biod_pa_wp_fig17_fn <- file.path(wkdir,'biod_pa_wp_fig17_Philippines_Marine_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig17_fn),show.output.on.console = TRUE)

## Figure 18: Top 4 marine priority areas in Madagascar's EEZ
source(file.path(wkdir,'biod_pa_wp_fig18_top4_priorities_madagascar.R'))

## Figure 19:  Madagascar - Marine species protection vs. territory in EEZ
biod_pa_wp_fig19_fn <- file.path(wkdir,'biod_pa_wp_fig19_Madagascar_Marine_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig19_fn),show.output.on.console = TRUE)

## Figure 20a:  Northern India - New protected areas for complete species coverage
## Figure 20b:  Eastern India - New protected areas for complete species coverage
## Figure 20c:  Southern India - New protected areas for complete species coverage
#source(file.path(wkdir,'biod_pa_wp_fig20_india_protected_areas_in_subregions.R'))

## Figure 21:  India:  Species protection vs. land in protected areas
biod_pa_wp_fig21_fn <- file.path(wkdir,'biod_pa_wp_fig21_India_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig21_fn),show.output.on.console = TRUE)

## Figure 22:  China:  New protected areas for complete species coverage
#source(file.path(wkdir,'biod_pa_wp_fig22_china_protected_areas.R'))

## Figure 23:  China - Species protection vs. land in protected areas
biod_pa_wp_fig23_fn <- file.path(wkdir,'biod_pa_wp_fig23_China_Percents.do')
system(paste(stata_path, "/e do", biod_pa_wp_fig23_fn),show.output.on.console = TRUE)

##
## Tables
##

## Table 2:  South Africa - Species in top 3 protected areas
source(file.path(wkdir,'biod_pa_wp_tbl02_SouthAfrica_species.R'))

## Table 3:  South Africa - Distributions of new priority areas and species
source(file.path(wkdir,'biod_pa_wp_tbl03_SouthAfrica_new_priority_areas.R'))

## Table 4:  Costa Rica - Species in Top 3 New Protected Area
source(file.path(wkdir,'biod_pa_wp_tbl04_CostaRica_top3.R'))

## Table 5:  Costa Rica - Distributions of new priority areas and species
source(file.path(wkdir,'biod_pa_wp_tbl05_CostaRica_new_priority_areas.R'))

## Table 6:  India - Distributions of new priority areas and species
source(file.path(wkdir,'biod_pa_wp_tbl06_India_new_priority_areas.R'))

## Table 7:  China - Distributions of new priority areas and species
source(file.path(wkdir,'biod_pa_wp_tbl07_China_new_priority_areas.R'))

print(Sys.time())
