## Implementing 30x30: Lessons From Country Case Studies
## Authors: Susmita Dasgupta, Brian Blankespoor, David Wheeler
## Figure 6c:  Cameroon - Unprotected species

# PA Cameroun
pa_cmr_fn <- file.path(getwd(),'local_data/geo_data/Cameroon_PA/Cameroon_PA.shp')
wdpa_sf_i <- st_read(pa_cmr_fn)

#
species_fn <- file.path(getwd(),'local_data/geo_data/species/cameroon_species.xlsx')
species_list <- readxl::read_excel(species_fn) %>%
  dplyr::filter(species_group == 'Arthropods') %>%
  dplyr::select(species) %>%
  arrange() %>%
  pull()

print(sprintf("%s species in list",length(species_list)))

species_sf_fig06c_fn <- file.path(wkdir,'local_data','geo_data','species','species_fig06c.Rdata')
xfun::dir_create(dirname(species_sf_fig06c_fn))
if(!file.exists(species_sf_fig06c_fn)){
  # load species shapes from species listed in xlsx
  source(file.path(wkdir,'load_species_shapefiles.R'))
  saveRDS(species_sf,species_sf_fig06c_fn)
} else {
  species_sf <- readr::read_rds(species_sf_fig06c_fn)
}

# add
species_sf <- species_sf %>%
  dplyr::mutate(species_unprotected = 'Occurrence Regions of\nSelected Unprotected\nEndemic Species')

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# add
wdpa_sf_i <- wdpa_sf_i %>%
  dplyr::mutate(Protected = 'Protected Area')

# global admin0 subset
admin0_sf_i = admin0_sf %>%
  dplyr::filter(NAME_EN=="Cameroon")

# Extract the bounding box of the max area polygon sf object
adm0bbox <- admin0_sf_i %>%
  st_cast(.,"POLYGON") %>%
  dplyr::mutate(area_km2 = st_area(.)) %>%
  slice_max(area_km2,n = 1) %>%
  st_bbox()

# map
# Occurrence Regions of Selected Unprotected Endemic Species
p6c <- ggplot() +
  geom_sf(data = admin0_sf_i, color = 'grey90') +
  geom_sf(data = species_sf, aes(fill=species_unprotected),color=NA,alpha = 0.9) +
  geom_sf(data = wdpa_sf_i, aes(fill=Protected), color = 'darkgreen') +
  scale_fill_manual(values = c("Protected Area" = "darkgreen",
                               "Occurrence Regions of\nSelected Unprotected\nEndemic Species" = "red")) +
  coord_sf(xlim = c(adm0bbox["xmin"], adm0bbox["xmax"]),
           ylim = c(adm0bbox["ymin"], adm0bbox["ymax"]),
           expand = FALSE  # To prevent any additional padding around the edges
           ) +
  mytheme +
  labs(fill = "") +
  # drop axis labels per reviewer comment
  theme(legend.position="right",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))

p6c_fn <- file.path(figdir,paste0('fig_06c_unprotected_cameroun_arthropods',Sys.Date(),'.png'))
ggsave(p6c_fn, p6c, dpi=500, width = 7.875, height = 6, units='in')
