
# PA
pa_iso3_fn <- file.path(getwd(),'local_data/geo_data/Cameroon_PA/Cameroon_PA.shp')
wdpa_sf_i <- st_read(pa_iso3_fn)

# add
wdpa_sf_i <- wdpa_sf_i %>%
  dplyr::mutate(Protected = 'Protected Area')

# dir
iso3_top4dir <- file.path(wkdir,'local_data','geo_data','Cameroon_top4')

# critical species counts
cspp1 <- rast(file.path(iso3_top4dir,'Cameroon_Critical_Species_Counts_1.tif'))
cspp2 <- rast(file.path(iso3_top4dir,'Cameroon_Critical_Species_Counts_2.tif'))
cspp3 <- rast(file.path(iso3_top4dir,'Cameroon_Critical_Species_Counts_3.tif'))
cspp4 <- rast(file.path(iso3_top4dir,'Cameroon_Critical_Species_Counts_4.tif'))
s_cspp <- c(cspp1,cspp2,cspp3,cspp4)
rstk_cspp <- raster::stack(s_cspp)
names(rstk_cspp) <- c('Priority_1','Priority_2','Priority_3','Priority_4')

cprv1 <- st_read(file.path(iso3_top4dir,'Cameroon_Critical_Species_Prov_1.shp')) %>%
  dplyr::mutate(band = 'Priority 1')
cprv2 <- st_read(file.path(iso3_top4dir,'Cameroon_Critical_Species_Prov_2.shp')) %>%
  dplyr::mutate(band = 'Priority 2')
cprv3 <- st_read(file.path(iso3_top4dir,'Cameroon_Critical_Species_Prov_3.shp')) %>%
  dplyr::mutate(band = 'Priority 3')
cprv4 <- st_read(file.path(iso3_top4dir,'Cameroon_Critical_Species_Prov_4.shp')) %>%
  dplyr::mutate(band = 'Priority 4')

cprv_dt <- data.table::rbindlist(list(cprv1,cprv2,cprv3,cprv4))
cprv_sf <- st_as_sf(cprv_dt) %>%
  dplyr::mutate(label = 'Province\nwith maximum\ncount')

# global admin0 subset
admin0_sf_i = wbbnd_ddh %>%
  dplyr::filter(NAME_EN=="Cameroon")
## Implementing 30x30: Lessons From Country Case Studies
## Authors: Susmita Dasgupta, Brian Blankespoor, David Wheeler
## Figure 7: Top 4 priority areas in Cameroon

# Extract the bounding box of the max area polygon sf object
adm0bbox <- admin0_sf_i %>%
  st_cast(.,"POLYGON") %>%
  dplyr::mutate(area_km2 = st_area(.)) %>%
  slice_max(area_km2,n = 1) %>%
  st_bbox()

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

require(stars)

# Convert the stars object to a data frame
raster_df <- as.data.frame(st_as_stars(rstk_cspp), xy = TRUE)
names(raster_df)[4] <- 'decile'
# replace "_" with a space
raster_df$band <- gsub("_", " ", raster_df$band)
  
# map
# Occurrence Regions of Selected Unprotected Endemic Species
p7_panel <- ggplot() +
  geom_sf(data = wbbnd_ddh, fill = 'grey95', color = NA) +
  geom_sf(data = admin0_sf_i, fill = 'grey90', color = 'grey80') +
  geom_raster(data=raster_df,aes(x = x, y = y, fill = factor(decile))) +  # Use 'value' as the fill aesthetic
  scale_fill_viridis_d('Species counts\n(decile)',
                       direction=-1,
                       option='rocket') +  # Optional: Use a color scale like viridis
  ggnewscale::new_scale_fill() +
  geom_sf(data = wdpa_sf_i, aes(fill=Protected), color = 'darkgreen') +
  geom_sf(data = cprv_sf, fill = NA, aes(color = label)) +
  
  scale_fill_manual(values = c("Protected Area" = "darkgreen")) +
  scale_color_manual(values = c("Province\nwith maximum\ncount" = "purple")) +
  
  coord_sf(xlim = c(adm0bbox["xmin"], adm0bbox["xmax"]),
           ylim = c(adm0bbox["ymin"], adm0bbox["ymax"]),
           expand = FALSE  # To prevent any additional padding around the edges
  ) +
  mytheme +
  labs(fill = "", color = "") +
  # drop axis labels per reviewer comment
  theme(legend.position="right",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  facet_wrap(~ band, ncol = 2)
  
ppanel_fn <- file.path(figdir,paste0('fig_07_panel_cameroon_',Sys.Date(),'.png'))
ggsave(ppanel_fn, p7_panel, dpi=500, width = 7, height = 7.875, units='in')
