
# PA Brazil
pa_bra_fn <- file.path(getwd(),'local_data/geo_data/Brazil_PA/Brazil_PA.shp')
wdpa_bra_i <- st_read(pa_bra_fn)

# PA Cameroon
pa_cmr_fn <- file.path(getwd(),'local_data/geo_data/Cameroon_PA/Cameroon_PA.shp')
wdpa_cmr_i <- st_read(pa_cmr_fn)
wdpa_i <- data.table::rbindlist(list(wdpa_bra_i,wdpa_cmr_i)) %>% st_as_sf()
wdpa_sf_i <- wdpa_i %>%
  dplyr::mutate(Protected = 'Protected Area')

# Brazil
iso3_fulldir <- file.path(wkdir,'local_data','geo_data','Brazil_full_protection')
cprvBR <- st_read(file.path(iso3_fulldir,'Brazil_Critical_Species_Prov_1.shp')) %>%
  dplyr::mutate(band = sprintf("%s, %s", NAME_0,NAME_1)) %>% 
  st_cast(.,"MULTIPOLYGON")

cmaxBR <- st_read(file.path(iso3_fulldir,'Brazil_Critical_Species_Max_1.shp')) %>%
  dplyr::mutate(band = cprvBR$band) 
ccovBR <- st_read(file.path(iso3_fulldir,'Brazil_Group_1_Full_Coverage.shp')) %>%
  dplyr::mutate(band = cprvBR$band) %>% st_cast(.,"MULTIPOLYGON")

# Extract the bounding box of the max area polygon sf object
adm0bbox <- cprvBR %>%
  st_cast(.,"POLYGON") %>%
  dplyr::mutate(area_km2 = st_area(.)) %>%
  slice_max(area_km2,n = 1) %>%
  st_bbox()

# Cameroon
iso3_fulldir <- file.path(wkdir,'local_data','geo_data','Cameroon_full_protection')
cprvCM <- st_read(file.path(iso3_fulldir,'Cameroon_Critical_Species_Prov_1.shp')) %>%
  dplyr::mutate(band = sprintf("%s, %s", NAME_0,NAME_1)) %>% 
  st_cast(.,"MULTIPOLYGON")
cprvCM$band

cmaxCM <- st_read(file.path(iso3_fulldir,'Cameroon_Critical_Species_Max_1.shp')) %>%
  dplyr::mutate(band = cprvCM$band) 

ccovCM <- st_read(file.path(iso3_fulldir,'Cameroon_Group_1_Full_Coverage.shp')) %>%
  dplyr::mutate(band = cprvCM$band) %>% st_cast(.,"MULTIPOLYGON")

# global admin0 subset
admin0_sf_i = wbbnd_ddh %>%
  dplyr::filter(NAME_EN %in% c("Brazil","Cameroon")) %>%
  dplyr::mutate(band = NAME_EN)

# rbind
cmax <- data.table::rbindlist(list(cmaxBR,cmaxCM)) %>% st_as_sf()
cprv <- data.table::rbindlist(list(cprvBR,cprvCM)) %>% st_as_sf() %>%
  mutate(
    x_min = ifelse(band == "Cameroon, Centre", st_bbox(cprvCM)["xmin"], st_bbox(adm0bbox)["xmin"]),
    x_max = ifelse(band == "Cameroon, Centre", st_bbox(cprvCM)["xmax"], st_bbox(adm0bbox)["xmax"]),
    y_min = ifelse(band == "Cameroon, Centre", st_bbox(cprvCM)["ymin"], st_bbox(adm0bbox)["ymin"]),
    y_max = ifelse(band == "Cameroon, Centre", st_bbox(cprvCM)["ymax"], st_bbox(adm0bbox)["ymax"])
  )

ccov <- data.table::rbindlist(list(ccovBR,ccovCM)) %>% st_as_sf()
  

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 12)
                 ,plot.subtitle = element_text(size = 12)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# 
g <- purrr::map(cprv$band,
                function(X) {
                  ggplot() +
                    ggtitle(filter(cprv,band == X)$band) + 
                    geom_sf(data = wbbnd_ddh, fill = 'grey90', color = NA) +
                    geom_sf(data = filter(cprv,band == X), color = 'grey50') +
                    geom_sf(data = wdpa_sf_i, 
                            fill='darkgreen', color = NA) +
                    geom_sf(data = filter(ccov,band == X), fill = NA, 
                            color = 'purple') +
                    geom_sf(data = filter(cmax, band == X), 
                            fill = NA, color = 'purple',
                            shape = 15) +
                    mytheme +
                    labs(fill = "", color = "") +
                    # drop axis labels per reviewer comment
                    theme(legend.position="bottom",
                          axis.text.x = element_blank(),
                          axis.text.y = element_blank(),
                          axis.ticks = element_blank()) + 
                    coord_sf(xlim = c(filter(cprv,band == X)$x_min, 
                                      filter(cprv,band == X)$x_max),
                             ylim = c(filter(cprv,band == X)$y_min, 
                                      filter(cprv,band == X)$y_max),
                             expand = FALSE  # To prevent any additional padding around the edges
                    )
                  
                })

p8_panel <- g[[1]] + g[[2]] + 
  patchwork::plot_layout(guides = "collect") + # Collect guides (legends) together
  patchwork::plot_annotation(tag_levels = 'A') 
p8_panel

ppanel_fn <- file.path(figdir,paste0('fig_08_panel_full_protection_',Sys.Date(),'.png'))
ggsave(ppanel_fn, p8_panel, dpi=500, width = 6.5, height = 4, units='in')
