
# PA Ecuador
pa_ecu_fn <- file.path(getwd(),'local_data/geo_data/Ecuador_PA/Ecuador_PA.shp')
wdpa_sf_i <- st_read(pa_ecu_fn)

# PA pts
rpcts_ecu_fn <- file.path(getwd(),'local_data/geo_data/Ecuador_PA/Ecuador_RPcts.shp')
rpcts_i <- st_read(rpcts_ecu_fn)
table(rpcts_i$pctgrp)

# factor
rpcts_i <- rpcts_i %>%
  dplyr::mutate(pctgrp10 = factor(cut(pctgrp, 
    breaks = seq(10,100,by=10),  # Define breakpoints (open on the left, closed on the right)
    labels = c("10-20", "20-30", "30-40","40-50",
               "50-60", "60-70","70-80","80-90","90-100"),  # Labels for the factor levels
    right = FALSE)))  # Right-open intervals
table(rpcts_i$pctgrp10)

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# add
wdpa_sf_i <- wdpa_sf_i %>%
  dplyr::mutate(Protected = 'Protected Area')

# global admin0 subset
admin0_sf_i = admin0_sf %>%
  dplyr::filter(NAME_EN=="Ecuador")

# Extract the bounding box of the max area polygon sf object
adm0bbox <- admin0_sf_i %>%
  st_cast(.,"POLYGON") %>%
  dplyr::mutate(area_km2 = st_area(.)) %>%
  slice_max(area_km2,n = 1) %>%
  st_bbox()

# map
# Occurrence Regions of Selected Unprotected Endemic Species
p12 <- ggplot() +
  geom_sf(data = admin0_sf, fill = 'white', color = NA) +
  geom_sf(data = admin0_sf_i, fill = 'grey90') +
  geom_sf(data = wdpa_sf_i, fill='darkgreen', color = 'darkgreen') +
  geom_sf(data = rpcts_i, fill='red',color='red',alpha = 0.9) +
  coord_sf(xlim = c(adm0bbox["xmin"], adm0bbox["xmax"]),
           ylim = c(adm0bbox["ymin"], adm0bbox["ymax"]),
           expand = FALSE  # To prevent any additional padding around the edges
           ) +
  mytheme +
  labs(fill = "") +
  # drop axis labels per reviewer comment
  theme(legend.position="right",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  #theme(legend.key = element_rect(fill = "white")) +
  #theme(strip.background =element_rect(fill="gray92")) + 
  facet_wrap(~ pctgrp10, ncol = 3)  # Facet by the PCT group

p12_fn <- file.path(figdir,paste0('fig_12_panel_ecuador',Sys.Date(),'.png'))
ggsave(p12_fn, p12, dpi=500, width = 6, height = 8, units='in')
