
# PA
pa_iso3_fn <- file.path(getwd(),'local_data/geo_data/Madagascar_top4/MadagascarMarine_PA.shp')
wdpa_sf_i <- st_read(pa_iso3_fn)
wdpa_sf_i <- wdpa_sf_i %>%
  dplyr::mutate(Protected = 'Protected Area')

eez_fn <- file.path(getwd(),'local_data/geo_data/Madagascar_top4/Madagascar EEZ.shp')
eez_sf_i <- st_read(eez_fn)

# dir
iso3_top4dir <- file.path(wkdir,'local_data','geo_data','Madagascar_top4')

# critical species counts
cspp1 <- rast(file.path(iso3_top4dir,'Madagascar_Critical_Species_Counts_1.tif'))
cspp2 <- rast(file.path(iso3_top4dir,'Madagascar_Critical_Species_Counts_2.tif'))
cspp3 <- rast(file.path(iso3_top4dir,'Madagascar_Critical_Species_Counts_3.tif'))
cspp4 <- rast(file.path(iso3_top4dir,'Madagascar_Critical_Species_Counts_4.tif'))
s_cspp <- c(cspp1,cspp2,cspp3,cspp4)
rstk_cspp <- raster::stack(s_cspp)
names(rstk_cspp) <- c('Priority_1','Priority_2','Priority_3','Priority_4')

maxpt <- function(r){
  
  # Find the maximum value in the raster
  max_value <- global(r, "max", na.rm=TRUE)
  
  # Find the cell index of the maximum value
  max_cell_index <- which.max(values(r))
  
  # Get the coordinates of the maximum value cell
  max_cell_coordinates <- xyFromCell(r, max_cell_index)
  
  # Create a data frame with coordinates and the maximum value
  point_df <- data.frame(x = max_cell_coordinates[1], y = max_cell_coordinates[2], value = max_value)
  
  # Convert to sf object
  point_sf <- st_as_sf(point_df, coords = c("x", "y"), crs = st_crs(r))
  
  # buffer 
  point_sf_buf <- st_buffer(point_sf,dist=as.numeric(res(r)[1]))
  
  return(point_sf_buf)
}

# max value raster
cprv1 <- maxpt(cspp1) %>%  dplyr::mutate(band = 'Priority 1')
cprv2 <- maxpt(cspp2) %>%  dplyr::mutate(band = 'Priority 2')
cprv3 <- maxpt(cspp3) %>%  dplyr::mutate(band = 'Priority 3')
cprv4 <- maxpt(cspp4) %>%  dplyr::mutate(band = 'Priority 4')

cprv_dt <- data.table::rbindlist(list(cprv1,cprv2,cprv3,cprv4))
cprv_sf <- st_as_sf(cprv_dt) %>%
  dplyr::mutate(label = 'Pixel with\nmaximum\ncount')


# global admin0 subset
admin0_sf_i = wbbnd_ddh %>%
  dplyr::filter(NAME_EN=="Madagascar")

# Extract the bounding box of the max area polygon sf object
adm0bbox <- eez_sf_i %>%
  st_cast(.,"POLYGON") %>%
  dplyr::mutate(area_km2 = st_area(.)) %>%
  st_bbox()

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

require(stars)

# Convert the stars object to a data frame
raster_df <- as.data.frame(st_as_stars(rstk_cspp), xy = TRUE)
names(raster_df)[4] <- 'decile'
# replace "_" with a space
raster_df$band <- gsub("_", " ", raster_df$band)

# map
# Occurrence Regions of Selected Unprotected Endemic Species
p18_panel <- ggplot() +
  geom_sf(data = wbbnd_ddh, fill = 'grey95', color = NA) +
  geom_sf(data = admin0_sf_i, fill = 'grey90', color = 'grey80') +
  geom_sf(data = eez_sf_i, fill = '#87CEEB') +
  geom_raster(data=raster_df,aes(x = x, y = y, fill = factor(decile))) +  # Use 'value' as the fill aesthetic
  scale_fill_viridis_d('Species counts\n(decile)',
                       direction=-1,
                       option='rocket') +  # Optional: Use a color scale like viridis
  ggnewscale::new_scale_fill() +
  geom_sf(data = wdpa_sf_i, aes(fill=Protected), color = 'darkgreen') +
  geom_sf(data = cprv_sf, fill = NA, aes(color = label)) +
  scale_fill_manual(values = c("Protected Area" = "darkgreen")) +
  scale_color_manual(values = c("Pixel with\nmaximum\ncount" = "purple")) +
  
  coord_sf(xlim = c(adm0bbox["xmin"], adm0bbox["xmax"]),
           ylim = c(adm0bbox["ymin"], adm0bbox["ymax"]),
           expand = FALSE  # To prevent any additional padding around the edges
  ) +
  mytheme +
  labs(fill = "", color = "") +
  # drop axis labels per reviewer comment
  theme(legend.position="right",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  facet_wrap(~ band, ncol = 2)

ppanel_fn <- file.path(figdir,paste0('fig_18_panel_madagascar_',Sys.Date(),'.png'))
ggsave(ppanel_fn, p18_panel, dpi=500, width = 7, height = 8, units='in')
