###################################################################
##
##
###################################################################

today <- Sys.Date()

##
## local data
##

pa_dir <- file.path(wkdir,'local_data','geo_data','India Files')
pa_fn <- file.path(pa_dir,'India_PA.shp')
pa_admin <- st_read(pa_fn) %>%
  dplyr::mutate(pa = 'Protected area')

pa_rpct_fn <- file.path(pa_dir,'India_RPcts.shp')
pa_rpct <- st_read(pa_rpct_fn)

summary(pa_rpct$tcells)
table(pa_rpct$pctgrp)
n_pa_rpct_groups <- length(unique(pa_rpct$pctgrp))

tbreaks <- c(0,2,6,10,13,18,21,25,38,47,117)
pa_rpct <- pa_rpct %>%
  dplyr::mutate(f_pctgrp = factor(pctgrp)) %>%
  dplyr::mutate(f_tcells = cut(tcells, breaks = tbreaks, include.lowest = TRUE)
                ) %>%
  dplyr::relocate(geometry, .after = last_col())

levels(pa_rpct$f_tcells)
pa_rpct$f_tcells
pa_rpct <- st_set_crs(pa_rpct,4326)

#
a1 <- 1.5
r <- 1.516  # Common ratio
n <- 10  # Number of categories
# Generate the geometric sequence
geometric_sizes <- a1 * r^(0:(n-1))
scaled_geometric_sizes <- (geometric_sizes - min(geometric_sizes)) / (max(geometric_sizes) - min(geometric_sizes)) * (8 - a1) + a1

# Get the color palette for 9 categories (qualitative palette)
rpct_colors_only <- c('gray85',brewer.pal(9, "YlOrBr"))

# Create the named vector for rpct_colors
require(stringr)
rpct_colors_names <- setNames(rpct_colors_only,(levels(pa_rpct$f_tcells)))
rpct_size_names <- setNames(scaled_geometric_sizes,(levels(pa_rpct$f_tcells)))


##
## India
##
adm0 <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_10m.shp'))
adm0ind <- subset(adm0,ISO_A3=="IND")
adm0Disp <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_disputed_areas_10m.shp'))

adm0lines <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_boundary_lines_10m.shp'))
adm0linesDisp <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_boundary_lines_disputed_areas_10m.shp'))
adm0linesDisp_dashed <- subset(adm0linesDisp,WB_STYLE=="Tightly Dashed Line")
adm0linesDisp_dashed <- st_union(adm0linesDisp_dashed)
adm0linesDisp_dotted <- subset(adm0linesDisp,WB_STYLE=="Dotted Line")
adm0linesDisp_dotted <- st_union(adm0linesDisp_dotted)
adm0coastlines <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Coastlines_10m.shp'))

mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.grid.major = element_line(color = '#cccccc' 
                                                  ,linetype = 'dashed'
                                                  ,size = .3
                 )
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_text(size = 10),
                 axis.title.x = element_blank(),  # Remove x-axis title
                 axis.title.y = element_blank(),  # Remove y-axis title
                 axis.text.x = element_blank(),   # Remove x-axis labels (numbers)
                 axis.text.y = element_blank()    # Remove y-axis labels (numbers)
)

##
## Per guidelines map as a subregion
##

##
## NORTH
##
p_india_pa_north_fn <- file.path(figdir,paste0('fig_20a_protected_areas_north',today,'.png'))
p_india_pa_north <- ggplot() +  
  geom_sf(data=adm0, aes(fill="#E8E8E8"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0Disp, aes(fill="#F3F3F3"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0lines, color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0linesDisp_dashed, linetype = "dashed", color="#000000", show.legend = FALSE, lwd = 0.25) + 
  geom_sf(data=adm0linesDisp_dotted, linetype = "dotted", color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0coastlines, color="#7D95CE", show.legend = FALSE) +
  geom_sf(data=pa_admin, aes(fill=pa), color = NA) +
  scale_fill_manual(values = c("Protected area" = 'darkgreen')) +
  geom_sf(data=pa_rpct, aes(color=f_tcells,size = f_tcells)) +
  scale_color_manual(values = rpct_colors_names,'New Species\nProtected') +  # Manually assigning colors
  scale_size_manual(values = rpct_size_names) +  # Set custom sizes for each category
  
  coord_sf(xlim = c(67,80),
           ylim = c(18,32.5),
           expand = FALSE) +
  theme(legend.position="right", legend.direction="vertical") +
  guides(
    fill = guide_legend(title = ""), 
    size = guide_legend(title = "New Species\nProtected", 
                        override.aes = list(color = rpct_colors_names, size = rpct_size_names))
  ) +
  mytheme

ggsave(p_india_pa_north_fn,p_india_pa_north,dpi=500,width = 6, height = 5, units = "in")


##
## EAST
## 
p_india_pa_east_fn <- file.path(figdir,paste0('fig_20b_protected_areas_east',today,'.png'))
p_india_pa_east <- ggplot() +  
  geom_sf(data=adm0, aes(fill="#E8E8E8"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0Disp, aes(fill="#F3F3F3"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0lines, color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0linesDisp_dashed, linetype = "dashed", color="#000000", show.legend = FALSE, lwd = 0.25) + 
  geom_sf(data=adm0linesDisp_dotted, linetype = "dotted", color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0coastlines, color="#7D95CE", show.legend = FALSE) +
  geom_sf(data=pa_admin, aes(fill=pa), color = NA) +
  scale_fill_manual(values = c("Protected area" = 'darkgreen')) +
  geom_sf(data=pa_rpct, aes(color=f_tcells,size = f_tcells)) +
  scale_color_manual(values = rpct_colors_names,'New Species\nProtected') +  # Manually assigning colors
  scale_size_manual(values = rpct_size_names) +  # Set custom sizes for each category
  # Add a rectangle in the upper-right corner
  annotate("rect", xmin = 91.5, xmax = 97.5, ymin = 26.82, ymax = 30, 
           fill = "white", color = "gray50", size = 0.5, alpha = 1) +
  # Add text inside the rectangle
  annotate("text", x = ((91.5+97.5)/2), y = ((26.8 + 30) /2), 
           label = "New Species Protected\nand Protected areas",
           fontface = "bold",
           size = 2.5,
           color = "black", 
           hjust = 0.5, vjust = 0.5)+
  coord_sf(xlim = c(80,97.5),
           ylim = c(18,30),
           expand = FALSE) +
  theme(legend.position="right", legend.direction="vertical",
        legend.text = element_text(size = 10),
          axis.title.x = element_blank(),
          axis.title.y = element_blank(),
          axis.text.x = element_blank(),  # Removes x axis ticks
          axis.text.y = element_blank(),   # Removes y axis ticks
        ) +  # Set legend text size) +
  guides(
    fill = guide_legend(title = ""), 
    size = guide_legend(title = "New Species\nProtected", 
                        override.aes = list(color = rpct_colors_names, size = rpct_size_names))
  )
  
  
ggsave(p_india_pa_east_fn,p_india_pa_east,dpi=500,width = 6, height = 5, units = "in")


##
## SOUTH
##
p_india_pa_south_fn <- file.path(figdir,paste0('fig_20c_protected_areas_south',today,'.png'))
p_india_pa_south <- ggplot() +  
  geom_sf(data=adm0, aes(fill="#E8E8E8"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0Disp, aes(fill="#F3F3F3"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0lines, color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0linesDisp_dashed, linetype = "dashed", color="#000000", show.legend = FALSE, lwd = 0.25) + 
  geom_sf(data=adm0linesDisp_dotted, linetype = "dotted", color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=adm0coastlines, color="#7D95CE", show.legend = FALSE) +
  geom_sf(data=pa_admin, aes(fill=pa), color = NA) +
  scale_fill_manual(values = c("Protected area" = 'darkgreen')) +
  geom_sf(data=pa_rpct, aes(color=f_tcells,size = f_tcells)) +
  scale_color_manual(values = rpct_colors_names,'New Species\nProtected') +  # Manually assigning colors
  scale_size_manual(values = rpct_size_names) +  # Set custom sizes for each category
  coord_sf(xlim = c(72.5,85),
           ylim = c(8,20),
           expand = FALSE) +
  theme(legend.position="right", legend.direction="vertical") +
  guides(
    fill = guide_legend(title = ""), 
    size = guide_legend(title = "New Species\nProtected", 
                        override.aes = list(color = rpct_colors_names, size = rpct_size_names))
  ) +
  mytheme
ggsave(p_india_pa_south_fn,p_india_pa_south,dpi=500,width = 6, height = 5, units = "in")
