###################################################################
##
##
###################################################################

today <- Sys.Date()

##
## local data
##

pa_dir <- file.path(wkdir,'local_data','geo_data','China Files')
pa_fn <- file.path(pa_dir,'China_PA.shp')
pa_admin <- st_read(pa_fn) %>%
  dplyr::mutate(pa = 'Protected area')

pa_rpct_fn <- file.path(pa_dir,'China_RPcts.shp')
pa_rpct <- st_read(pa_rpct_fn)
n_pa_rpct_groups <- length(unique(pa_rpct$pctgrp))

tbreaks <- c(0,2,6,10,15,21,28,37,52,73,104)
pa_rpct <- pa_rpct %>%
  dplyr::mutate(f_pctgrp = factor(pctgrp)) %>%
  dplyr::mutate(f_tcells = cut(tcells, breaks = tbreaks, include.lowest = TRUE)
                ) %>%
  dplyr::relocate(geometry, .after = last_col())

pa_rpct$f_tcells
pa_rpct <- st_set_crs(pa_rpct,4326)

# parameters for scale point sizes
a1 <- 1.5
r <- 1.516  # Common ratio
n <- 10  # Number of categories
# Generate the geometric sequence
geometric_sizes <- a1 * r^(0:(n-1))
scaled_geometric_sizes <- (geometric_sizes - min(geometric_sizes)) / (max(geometric_sizes) - min(geometric_sizes)) * (8 - a1) + a1

# Get the color palette for 9 categories (qualitative palette)
rpct_colors_only <- c('gray85',brewer.pal(9, "YlOrBr"))

# Create the named vector for rpct_colors
require(stringr)
rpct_colors_names <- setNames(rpct_colors_only,(levels(pa_rpct$f_tcells)))
rpct_size_names <- setNames(scaled_geometric_sizes,(levels(pa_rpct$f_tcells)))


##
## China
##
adm0 <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_10m.shp'))
# subset china from global
adm0chn <- subset(adm0,ISO_A3=="CHN")

adm0Disp <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_disputed_areas_10m.shp'))

adm0lines <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_boundary_lines_10m.shp'))
adm0linesDisp <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Admin0_boundary_lines_disputed_areas_10m.shp'))
adm0linesDisp_dashed <- subset(adm0linesDisp,WB_STYLE=="Tightly Dashed Line")
adm0linesDisp_dashed <- st_union(adm0linesDisp_dashed)
adm0linesDisp_dotted <- subset(adm0linesDisp,WB_STYLE=="Dotted Line")
adm0linesDisp_dotted <- st_union(adm0linesDisp_dotted)
adm0coastlines <- read_sf(paste0(wkdir,'/local_data/geo_data/Boundary_Data_10mil/WB_Coastlines_10m.shp'))

mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.grid.major = element_line(color = '#cccccc' 
                                                  ,linetype = 'dashed'
                                                  ,size = .3
                 )
                 ,panel.background = element_rect(fill = 'aliceblue')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_text(size = 10),
                 axis.title.x = element_blank(),  # Remove x-axis title
                 axis.title.y = element_blank(),  # Remove y-axis title
                 axis.text.x = element_blank(),   # Remove x-axis labels (numbers)
                 axis.text.y = element_blank()    # Remove y-axis labels (numbers)
)

## Per guidelines create map with legend placement

# Define coordinates for the polygon
st_bbox(adm0chn)
polygon_coords <- data.frame(
  x = c(72.5, 72.5, 82, 82, 98, 98, 72.5),  # X coordinates for the polygon
  y = c(18, 38, 38, 30, 30, 18, 18)     # Y coordinates for the polygon
)

##
## China
##
p_china_pa_fn <- file.path(figdir,paste0('fig_22_protected_areas_',today,'.png'))
p_china_pa <- ggplot() +  
  geom_sf(data=adm0chn, aes(fill="#E8E8E8"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0Disp, aes(fill="#F3F3F3"), show.legend = FALSE, lwd = NA) +
  geom_sf(data=adm0linesDisp_dashed, linetype = "dashed", color="#000000", show.legend = FALSE, lwd = 0.25) + 
  geom_sf(data=adm0linesDisp_dotted, linetype = "dotted", color="#000000", show.legend = FALSE, lwd = 0.25) +
  geom_sf(data=pa_admin, aes(fill=pa), color = NA) +
  scale_fill_manual(values = c("Protected area" = 'darkgreen')) +
  geom_sf(data=pa_rpct, aes(color=f_tcells,size = f_tcells)) +
  scale_color_manual(values = rpct_colors_names,'New Species\nProtected') +  # Manually assigning colors
  scale_size_manual(values = rpct_size_names) +  # Set custom sizes for each category
  # add boxes per requirement
  # Add a rectangle in the lower left corner
  annotate("polygon", 
           x = polygon_coords$x, 
           y = polygon_coords$y,
           fill = "white", color = "gray50", size = 0.5, alpha = 1) +
  # Add text inside the rectangle
  annotate("text", x = ((73+98)/2), y = ((18 + 30) /2), 
           label = "New Species Protected\nand Protected areas",
           fontface = "bold",
           size = 2.5,
           color = "black", 
           hjust = 0.5, vjust = 0.5)+
  
  coord_sf(xlim = c(75,133),
           ylim = c(19,52)) +
  theme(legend.position="right", legend.direction="vertical") +
  guides(
    fill = guide_legend(title = ""), 
    size = guide_legend(title = "New Species\nProtected", 
                        override.aes = list(color = rpct_colors_names, size = rpct_size_names))
  ) +
  mytheme

ggsave(p_china_pa_fn,p_china_pa,dpi=500,width = 8, height = 5, units = "in")
