##
## Table 4:  Costa Rica - Species in Top 3 New Protected Area
##

##
tbl04_fn <- file.path(wkdir,'local_data','tab_data','tbl04_costa_rica_top3.xlsx')
tbl04 <- readxl::read_excel(tbl04_fn)

# Loop through each unique Group/column value
for (tblcol_i in unique(tbl04$Col)) {
  print(tblcol_i)

  tbl_i <- tbl04 %>% dplyr::filter(Col == tblcol_i)
  #
  max_items <- max(table(tbl_i$Group))
  for (grp_i in unique(tbl_i$Group)) {
    tbl_rows <- tbl_i %>% filter(Group == grp_i)
    n_needed <- max_items - nrow(tbl_rows)  # Calculate the number of rows needed for Vertebrates
    
    # Step 2: Create additional rows filled with NA for Vertebrates
    additional_rows <- tibble(
      Col = rep(tblcol_i, n_needed),         # Add same group (1) for Vertebrates
      Species = rep(NA, n_needed),      # Add NAs for species
      SpeciesGroup = rep(SpeciesGroup_i, n_needed),
      Group = rep(grp_i, n_needed)
      # Specify Vertebrates for the SpeciesGroup
    )
    
    tbl_i <- rbind(tbl_i,additional_rows)
  }
  
  # long to wide
  tbl04_wide_data <- tbl_i %>%
    dplyr::select(-c(Group,Col)) %>%
    pivot_wider(
      names_from = SpeciesGroup,    # Spread out by SpeciesGroup (e.g., Vertebrates, Plants, etc.)
      values_from = Species,        # Use the species names as values
      values_fill = NA  # Fill missing values with NA
    ) %>%
    unnest(cols = unique(tbl_i$SpeciesGroup))
  
  tbl04_wide_data2_fn <- file.path(tbldir,sprintf('tbl_04_column%s.csv',tblcol_i))
  write.csv(tbl04_wide_data,tbl04_wide_data2_fn,row.names=F)
}
